/**
 * The gMobilab driver was contributed by:
 * GNU/Linux version by Lucie Daubigney from Supelec Metz
 * Windows version by Andrea Villa from Universita' degli Studi di Milano
 * GNU/Linux - Windows drivers integration and revision by Enrico Calore from Universita' degli studi di Milano
 * Developed thanks to the support of g.tec medical engineering GmbH, Austria
 */

#ifndef __OpenViBE_AcquisitionServer_CDriverGTecGMobiLabPlus_H__
#define __OpenViBE_AcquisitionServer_CDriverGTecGMobiLabPlus_H__

#include "../ovasIDriver.h"
#include "../ovasCHeader.h"

#if defined TARGET_HAS_ThirdPartyGMobiLabPlusAPI

#if defined OVAS_OS_Windows
   #include <windows.h>
   #pragma comment(lib, "gMOBIlabplus.lib")
#endif // defined OVAS_OS_Windows

#include <string>
#include <gMOBIlabplus.h>

namespace OpenViBEAcquisitionServer
{
	class CDriverGTecGMobiLabPlus : public OpenViBEAcquisitionServer::IDriver
	{
	public:
	
		CDriverGTecGMobiLabPlus(OpenViBEAcquisitionServer::IDriverContext& rDriverContext);
		virtual ~CDriverGTecGMobiLabPlus(void);
		virtual void release(void);
		virtual const char* getName(void);

		virtual OpenViBE::boolean isFlagSet(
			const OpenViBEAcquisitionServer::EDriverFlag eFlag) const
		{
			return eFlag==DriverFlag_IsUnstable;
		}

		//configuration
		virtual OpenViBE::boolean isConfigurable(void);
		virtual OpenViBE::boolean configure(void);
		//initialisation
		virtual OpenViBE::boolean initialize(const OpenViBE::uint32 ui32SampleCountPerChannel, OpenViBEAcquisitionServer::IDriverCallback& rCallback);
		virtual OpenViBE::boolean uninitialize(void);
		virtual const OpenViBEAcquisitionServer::IHeader* getHeader(void);

		//acquisition
		virtual OpenViBE::boolean start(void);
		virtual OpenViBE::boolean stop(void);
		virtual OpenViBE::boolean loop(void);

	protected:

		//usefull data to communicate with OpenViBE
		OpenViBEAcquisitionServer::CHeader m_oHeader;
		OpenViBEAcquisitionServer::IHeader* m_pHeader;
		OpenViBEAcquisitionServer::IDriverCallback* m_pCallback;
		OpenViBE::uint32 m_ui32SampleCountPerSentBlock;//number of sample you want to send in a row
		OpenViBE::float32* m_pSample;//array containing the data to send to OpenViBE once they had been recovered from the gTec module

		//usefull data to communicate with the gTec module
		float m_fConversionFactor;
		OpenViBE::boolean m_bTestMode;
		OpenViBE::uint32 m_ui32DeviceIdentifier;
		std::string m_oPortName;
		_BUFFER_ST m_oBuffer;
		_AIN m_oAnalogIn;
		_DIO l_oDigitalInOut;
		HANDLE m_oDevice;
		__CFG m_oDeviceConfig;
		
		#if defined OVAS_OS_Windows
			OVERLAPPED m_pOverlapped;
			void* m_pEvent;
		#endif // defined OVAS_OS_Windows
		

	private:

		void allowAnalogInputs(OpenViBE::uint32 ui32ChannelIndex);
	};
};

#endif // TARGET_HAS_ThirdPartyGMobiLabPlusAPI

#endif // __OpenViBE_AcquisitionServer_CDriverGTecGMobiLabPlus_H__
